@@ -39,6 +39,7 @@
 #include <libanjuta/anjuta-plugin.h>
 #include <libanjuta/anjuta-c-plugin-factory.h>
 #include <libanjuta/interfaces/ianjuta-plugin-factory.h>
+#include <libanjuta/interfaces/ianjuta-preferences.h>
 
 
 enum
@@ -791,6 +792,7 @@ plugin_toggled (GtkCellRendererToggle *cell, char *path_str, gpointer data)
 	AnjutaPluginHandle *plugin;
 	gboolean enabled;
 	GHashTable *activated_plugins;
+	AnjutaPlugin* plugin_object;
 	
 	path = gtk_tree_path_new_from_string (path_str);
 	
@@ -803,9 +805,34 @@ plugin_toggled (GtkCellRendererToggle *cell, char *path_str, gpointer data)
 			    COL_PLUGIN, &plugin,
 			    -1);
 	
+	if (enabled)
+	{
+		plugin_object = g_hash_table_lookup (priv->activated_plugins, plugin);
+		if (plugin_object &&
+			IANJUTA_IS_PREFERENCES(plugin_object))
+		{
+			ianjuta_preferences_unmerge (IANJUTA_PREFERENCES (plugin_object),
+									   anjuta_shell_get_preferences (ANJUTA_SHELL (priv->shell), NULL),
+									   NULL);
+		}
+	}
 	enabled = !enabled;
 
 	activated_plugins = plugin_set_update (plugin_manager, plugin, enabled);
+	plugin_object = g_hash_table_lookup (priv->activated_plugins, plugin);
+	
+	/* Make sure that it appears in the preferences. This method
+		can only be called when the preferences dialog is active so
+		it should be save
+	*/
+	if (plugin_object &&
+		IANJUTA_IS_PREFERENCES(plugin_object))
+	{
+		ianjuta_preferences_merge (IANJUTA_PREFERENCES (plugin_object),
+								   anjuta_shell_get_preferences (ANJUTA_SHELL (priv->shell), NULL),
+								   NULL);
+	}
+	
 	update_enabled (GTK_TREE_MODEL (store), activated_plugins);
 	gtk_tree_path_free (path);
 }
@@ -1877,17 +1904,17 @@ anjuta_plugin_manager_select (AnjutaPluginManager *plugin_manager,
 		{
 			g_warning ("Plugin does not define Icon attribute");
 		}
-		if (!anjuta_plugin_description_get_string (desc,
-												  "Anjuta Plugin",
-												  "Name",
-												  &plugin_name))
+		if (!anjuta_plugin_description_get_locale_string (desc,
+														  "Anjuta Plugin",
+														  "Name",
+														  &plugin_name))
 		{
 			g_warning ("Plugin does not define Name attribute");
 		}
-		if (!anjuta_plugin_description_get_string (desc,
-												  "Anjuta Plugin",
-												  "Description",
-												  &plugin_desc))
+		if (!anjuta_plugin_description_get_locale_string (desc,
+														  "Anjuta Plugin",
+														  "Description",
+														  &plugin_desc))
 		{
 			g_warning ("Plugin does not define Description attribute");
 		}
@@ -2342,13 +2369,15 @@ anjuta_plugin_manager_activate_plugins (AnjutaPluginManager *plugin_manager,
 												  "Icon",
 											  &icon_filename))
 		{
-			gchar *title, *description;
-			anjuta_plugin_description_get_string (d, "Anjuta Plugin",
-												  "Name",
-												  &title);
-			anjuta_plugin_description_get_string (d, "Anjuta Plugin",
-												  "Description",
-												  &description);
+			gchar *title /*, *description */;
+			anjuta_plugin_description_get_locale_string (d, "Anjuta Plugin",
+														 "Name",
+														 &title);
+			/*
+			anjuta_plugin_description_get_locale_string (d, "Anjuta Plugin",
+														 "Description",
+														 &description);
+			*/
 			icon_path = g_strconcat (PACKAGE_PIXMAPS_DIR"/",
 									 icon_filename, NULL);
 			/* DEBUG_PRINT ("Icon: %s", icon_path); */
@@ -2359,6 +2388,7 @@ anjuta_plugin_manager_activate_plugins (AnjutaPluginManager *plugin_manager,
 						   icon_path);
 			g_free (icon_path);
 			g_free (icon_filename);
+			g_free (title);
 		}
 		
 		if (anjuta_plugin_description_get_string (d, "Anjuta Plugin",
