@@ -1,21 +1,33 @@
+/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
 /*
-    anjuta-utils.c
-    Copyright (C) 2003 Naba Kumar  <naba@gnome.org>
+ * anjuta-utils.c
+ * Copyright (C) Naba Kumar  <naba@gnome.org>
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ */
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+/**
+ * SECTION:anjuta-utils
+ * @title: Utilities
+ * @short_description: Utility functions
+ * @see_also: 
+ * @stability: Unstable
+ * @include: libanjuta/anjuta-utils.h
+ * 
+ */
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*/
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -26,6 +38,9 @@
 #include <stdlib.h>
 #include <sys/stat.h>
 #include <sys/types.h>
+#include <sys/fcntl.h>
+#include <sys/termios.h>
+#include <dirent.h>
 #include <unistd.h>
 #include <stdio.h>
 #include <string.h>
@@ -576,18 +591,35 @@ anjuta_util_glist_strings_dup (GList * list)
 	return new_list;
 }
 
-static gchar*
-get_real_path(const gchar *file_name)
+gchar*
+anjuta_util_get_real_path (const gchar *path)
 {
-	if (file_name)
+	if (path != NULL)
 	{
-		gchar path[PATH_MAX+1];
-		memset(path, '\0', PATH_MAX+1);
-		realpath(file_name, path);
-		return g_strdup(path);
+		gchar *result;
+#ifdef PATH_MAX
+		gchar buf[PATH_MAX+1];
+
+		result = realpath (path, buf);
+		if (result != NULL)
+		{
+			*(buf + PATH_MAX) = '\0'; /* ensure a terminator */
+			return g_strdup (buf);
+		}
+#else
+		char *buf;
+		/* the string returned by realpath should be cleaned with
+		   free(), not g_free() */
+		buf = realpath (path, NULL);
+		if (buf != NULL)
+		{
+			result = g_strdup (buf);
+			free (buf);
+			return result;
+		}
+#endif
 	}
-	else
-		return NULL;
+	return NULL;
 }
 
 /* Dedup a list of paths - duplicates are removed from the tail.
@@ -600,24 +632,27 @@ anjuta_util_glist_path_dedup(GList *list)
 	struct stat s;
 	for (tmp = list; tmp; tmp = g_list_next(tmp))
 	{
-		path = get_real_path((const gchar *) tmp->data);
-		if (0 != stat(path, &s))
+		path = anjuta_util_get_real_path ((const gchar *) tmp->data);
+		if (path)
 		{
-			g_free(path);
-		}
-		else
-		{
-			for (tmp1 = nlist; tmp1; tmp1 = g_list_next(tmp1))
+			if (stat (path, &s) != 0)
 			{
-				if (0 == strcmp((const char *) tmp1->data, path))
+				g_free(path);
+			}
+			else
+			{
+				for (tmp1 = nlist; tmp1; tmp1 = g_list_next(tmp1))
 				{
-					g_free(path);
-					path = NULL;
-					break;
+					if (0 == strcmp((const char *) tmp1->data, path))
+					{
+						g_free(path);
+						path = NULL;
+						break;
+					}
 				}
+				if (path)
+				nlist = g_list_prepend(nlist, path);
 			}
-			if (path)
-			nlist = g_list_prepend(nlist, path);
 		}
 	}
 	anjuta_util_glist_strings_free(list);
@@ -784,8 +819,8 @@ anjuta_util_convert_to_utf8 (const gchar *str)
 		if (error != NULL) {
 			g_warning ("g_locale_to_utf8 failed: %s\n", error->message);
 			g_error_free (error);
-			g_free (utf8_msg_string);
-			return NULL;
+			/* g_free (utf8_msg_string);
+			return NULL; */
 		}
 	}
 	return utf8_msg_string;
@@ -795,7 +830,8 @@ GList*
 anjuta_util_parse_args_from_string (const gchar* string)
 {
 	gboolean escaped;
-	gchar    quote;
+	gchar    quote = 0;
+	gboolean is_quote = FALSE;
 	gchar* buffer = g_new0(gchar, strlen(string) + 1);
 	const gchar *s;
 	gint     idx;
@@ -803,7 +839,6 @@ anjuta_util_parse_args_from_string (const gchar* string)
 	
 	idx = 0;
 	escaped = FALSE;
-	quote = (gchar)-1;
 	s = string;
 	
 	while (*s) {
@@ -820,23 +855,24 @@ anjuta_util_parse_args_from_string (const gchar* string)
 		} else if (*s == '\\') {
 			/* Current char is an escape */
 			escaped = TRUE;
-		} else if (*s == quote) {
+		} else if (is_quote && *s == quote) {
 			/* Current char ends a quotation */
-			quote = (gchar)-1;
+			is_quote = FALSE;
 			if (!isspace(*(s+1)) && (*(s+1) != '\0')) {
 				/* If there is no space after the quotation or it is not
 				   the end of the string */
 				g_warning ("Parse error while parsing program arguments");
 			}
 		} else if ((*s == '\"' || *s == '\'')) {
-			if (quote == (gchar)-1) {
+			if (!is_quote) {
 				/* Current char starts a quotation */
 				quote = *s;
+				is_quote = TRUE;
 			} else {
 				/* Just a quote char inside quote */
 				buffer[idx++] = *s;
 			}
-		} else if (quote > 0){
+		} else if (is_quote){
 			/* Any other char inside quote */
 			buffer[idx++] = *s;
 		} else if (isspace(*s)) {
@@ -857,7 +893,7 @@ anjuta_util_parse_args_from_string (const gchar* string)
 		args = g_list_append (args, g_strdup (buffer));
 		idx = 0;
 	}
-	if (quote > 0) {
+	if (is_quote) {
 		g_warning ("Unclosed quotation encountered at the end of parsing");
 	}
 	return args;
@@ -897,14 +933,17 @@ FIXME: Find a better algorithm, this seems ineffective */
 gboolean anjuta_util_diff(const gchar* uri, const gchar* text)
 {
 	GnomeVFSFileSize bytes_read;
-	
 	gchar* file_text;
-	
-	GnomeVFSHandle* handle = NULL;
 	GnomeVFSFileInfo info;
+	GnomeVFSHandle* handle = NULL;
 	
 	gnome_vfs_get_file_info(uri, &info, GNOME_VFS_FILE_INFO_DEFAULT);
 	
+	if (info.size == 0 && text == NULL)
+		return FALSE;
+	else if (info.size == 0 || text == NULL)
+		return TRUE;
+	
 	file_text = g_new0(gchar, info.size + 1);
 	
 	if (gnome_vfs_open(&handle, uri, GNOME_VFS_OPEN_READ != GNOME_VFS_OK))
@@ -927,11 +966,67 @@ gboolean anjuta_util_diff(const gchar* uri, const gchar* text)
 	}
 }
 
-/*
- * Sun specific implementations
- *
- */
-#ifdef sun
+gboolean
+anjuta_util_path_has_extension (const gchar *path, const gchar *ext)
+{
+	if (strlen (path) <= strlen (ext))
+		return FALSE;
+	if ((path[strlen (path) - strlen (ext) - 1] == '.') &&
+		(strcmp (&path[strlen (path) - strlen (ext)], ext) == 0))
+		return TRUE;
+	return FALSE;
+}
+
+gchar *
+anjuta_util_get_uri_mime_type (const gchar *uri)
+{
+	GnomeVFSURI *vfs_uri;
+	const gchar *path;
+	gchar *mime_type;
+	
+	g_return_val_if_fail (uri != NULL, NULL);
+	
+	vfs_uri = gnome_vfs_uri_new (uri);
+	if (vfs_uri)
+		path = gnome_vfs_uri_get_path (vfs_uri);
+	else
+		path = NULL;
+	
+	/* If Anjuta is not installed in system gnome prefix, the mime types 
+	 * may not have been correctly registed. In that case, we use the
+	 * following mime detection
+	 */
+	if (!path)
+	{
+		mime_type = gnome_vfs_get_mime_type (uri);
+	}
+	else if (anjuta_util_path_has_extension (path, "anjuta"))
+	{
+		mime_type = g_strdup ("application/x-anjuta");
+	}
+	else if (anjuta_util_path_has_extension (path, "prj"))
+	{
+		mime_type = g_strdup ("application/x-anjuta-old");
+	}
+	else if (anjuta_util_path_has_extension (path, "ui"))
+	{
+		mime_type = g_strdup ("text/xml");
+	}
+	else if (anjuta_util_path_has_extension (path, "glade"))
+	{
+		mime_type = g_strdup ("application/x-glade");
+	}
+	else
+	{
+		mime_type = gnome_vfs_get_mime_type (uri);
+	}
+	
+	if (vfs_uri)
+		gnome_vfs_uri_unref (vfs_uri);
+	return mime_type;
+}
+
+#ifndef HAVE_LIBUTIL
 #include <grp.h>
 
 static int ptym_open (char *pts_name);
@@ -1223,8 +1318,4 @@ int scandir(const char *dir, struct dirent ***namelist,
   return(i);
 }
 
-int alphasort (const struct dirent **a, const struct dirent **b)
-{
-    return (strcmp((*a)->d_name, (*b)->d_name));
-}
-#endif /* sun */
+#endif /* HAVE_LIBUTIL */
