@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 /*
@@ -174,7 +174,7 @@ npw_druid_fill_summary (NPWDruid* this)
 	guint i;
 	GString* text;
 
-	text = g_string_new (_("Confim the following information:\n\n"));
+	text = g_string_new (_("Confirm the following information:\n\n"));
 	
 	g_string_append (text,_("Project Type: "));
 	g_string_append (text, _(npw_header_get_name (this->header)));
@@ -230,7 +230,7 @@ static void
 cb_druid_insert_project_icon (NPWHeader* header, gpointer user_data)
 {
 	gint idx;
-	GnomeIconList* list = (GnomeIconList*)user_data;
+	GnomeIconList* list = GNOME_ICON_LIST (user_data);
 
 	idx = gnome_icon_list_append (list, npw_header_get_iconfile (header), _(npw_header_get_name (header)));
 	gnome_icon_list_set_icon_data (list, idx, header);
@@ -511,7 +511,7 @@ cb_save_valid_property (NPWProperty* property, gpointer user_data)
 				yes = anjuta_util_dialog_boolean_question (data->parent, is_directory ? 
 					_("Directory \"%s\" is not empty. Project creation could fail if some files "
 					  "cannot be written. Do you want to continue?") :
-					_("File \"%s\" already exists. Do you want to overwrite it ?"),
+					_("File \"%s\" already exists. Do you want to overwrite it?"),
 			       		value);
 
 				if (!yes)
@@ -770,7 +770,7 @@ static void
 npw_druid_add_default_property (NPWDruid* this)
 {
 	NPWValue* value;
-	const gchar* s;
+	gchar* s;
 	/* gchar* email; */
 	AnjutaPreferences* pref;
 
@@ -780,18 +780,20 @@ npw_druid_add_default_property (NPWDruid* this)
 	value = npw_value_heap_find_value (this->values, ANJUTA_PROJECT_DIRECTORY_PROPERTY);
 	s = anjuta_preferences_get (pref, "anjuta.project.directory");
 	npw_value_heap_set_value (this->values, value, s, NPW_VALID_VALUE);
-
+	g_free (s);
+	
 	/* Add user name */
 	value = npw_value_heap_find_value (this->values, USER_NAME_PROPERTY);
 	s = anjuta_preferences_get (pref, "anjuta.user.name");
 	if (!s || strlen(s) == 0)
 	{
-		s = g_get_real_name();
+		s = (gchar *)g_get_real_name();
 		npw_value_heap_set_value (this->values, value, s, NPW_VALID_VALUE);
 	}
 	else
 	{
 		npw_value_heap_set_value (this->values, value, s, NPW_VALID_VALUE);
+		g_free (s);
 	}
 	/* Add Email address */
 	value = npw_value_heap_find_value (this->values, EMAIL_ADDRESS_PROPERTY);
@@ -804,6 +806,7 @@ npw_druid_add_default_property (NPWDruid* this)
 		s = g_strconcat(s, "@", getenv("HOSTNAME"), NULL);
 	}
 	npw_value_heap_set_value (this->values, value, s, NPW_VALID_VALUE);
+	g_free (s);
 }
 
 /* Druid public functions
@@ -830,7 +833,7 @@ npw_druid_new (NPWPlugin* plugin)
 	xml = glade_xml_new (GLADE_FILE, NEW_PROJECT_DIALOG, NULL);
 	if ((this == NULL) || (xml == NULL))
 	{
-		anjuta_util_dialog_error (NULL, _("Unable to build project wizard user interface"));
+		anjuta_util_dialog_error (NULL, _("Unable to build project assistent user interface."));
 		g_free (this);
 
 		return NULL;
