@@ -42,7 +42,7 @@
 
 /*---------------------------------------------------------------------------*/
 
-#define ICON_FILE "anjuta-tools-plugin.png"
+#define ICON_FILE "anjuta-tools-plugin-48.png"
 #define MAX_TOOL_PANES 4
 
 /* Widget and signal name found in glade file
@@ -67,7 +67,7 @@ typedef struct
 	gboolean created;
 	GString* buffer;
 	IAnjutaEditor* editor;
-	guint position;
+	IAnjutaIterable *position;
 } ATPOutputContext;
 
 /* Execute information
@@ -400,12 +400,18 @@ atp_output_context_print (ATPOutputContext *this, const gchar* text)
 			}
 			else if (this == &this->execution->output)
 			{
-				/* Only for output data */
+				/* This is append to the tool name to give something
+				 * like "My tools (output)". It's used to name the message
+				 * pane where the output of the tool is send to
+				 */
 				str = _("(output)");
 			}
 			else
 			{
-				/* Only for error data */
+				/* This is append to the tool name to give something
+				 * like "My tools (error)". It's used to name the message
+				 * pane where the errors of the tool is send to
+				 */
 				str = _("(error)");
 			}
 			title = g_strdup_printf ("%s %s", this->execution->name, str);
@@ -482,7 +488,7 @@ static gboolean
 atp_output_context_print_result (ATPOutputContext *this, gint error)
 {
 	gboolean ok;
-	char buffer[33];
+	gchar* buffer;
 	IAnjutaMessageManager *man;
 
 	ok = TRUE;
@@ -497,13 +503,14 @@ atp_output_context_print_result (ATPOutputContext *this, gint error)
 		{
 			if (error)
 			{
-				ok = atp_output_context_print (this, _("Completed... unsuccessful with "));
-				sprintf (buffer, "%d", error);
-				ok &= atp_output_context_print (this, buffer);
+				buffer = g_strdup_printf (_("Completed unsuccessful with %d\n"),
+										  error);
+				ok = atp_output_context_print (this, buffer);
+				g_free (buffer);
 			}
 			else
 			{
-				ok = atp_output_context_print (this, _("Completed... successful"));
+				ok = atp_output_context_print (this, _("Completed successful\n"));
 			}
 			ok &= atp_output_context_print (this, "\n");
 			if (this->view)
@@ -662,7 +669,8 @@ atp_output_context_construct (ATPOutputContext *this,
 	this->execution = execution;
 	this->view = NULL;
 	this->buffer = NULL;
-
+	this->position = NULL;
+	
 	return atp_output_context_initialize (this, execution, type);
 }
 
@@ -682,6 +690,10 @@ atp_output_context_destroy (ATPOutputContext *this)
 	{
 		g_string_free (this->buffer, TRUE);
 	}
+	if (this->position)
+	{
+		g_object_unref (this->position);
+	}
 }
 
 /* Execution context
@@ -977,7 +989,7 @@ atp_user_tool_execute (GtkMenuItem *item, ATPUserTool* this)
 			ed = get_current_editor(docman);
 			if (ed != NULL)
 			{
-				input = ianjuta_editor_get_text (ed, 0, -1, NULL);
+				input = ianjuta_editor_get_text_all (ed, NULL);
 			}
 			break;
 		case ATP_TIN_SELECTION:
